from .client import *
from .error import *

WOWS_NA = "https://api.worldofwarships.com"
WOWS_ASIA = "https://api.worldofwarships.asia"
WOWS_EU = "https://api.worldofwarships.eu"
WOWS_RU = "https://api.worldofwarships.ru"



import asyncio
from aiowpi import WPIClient, WOWS_ASIA

async def main():
    wpi = WPIClient("???")
    print(await wpi.player.serch(WOWS_ASIA, "???"))
    pass


if __name__ == "__main__":
    asyncio.run(main())
